==> haskell-hedgehog-0.6.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hedgehog
version: 0.6.1
id: hedgehog-0.6.1-IgAF1DmaXgkJa0UuqSnSwG
key: hedgehog-0.6.1-IgAF1DmaXgkJa0UuqSnSwG
license: BSD-3-Clause
maintainer: Jacob Stanley <jacob@stanley.io>
author: Jacob Stanley
homepage: https://hedgehog.qa
synopsis: Hedgehog will eat all your bugs.
description:
    Hedgehog is a modern property-based testing system, in the spirit of
    QuickCheck. Hedgehog uses integrated shrinking, so shrinks obey the
    invariants of generated values by construction.
    .
    To get started quickly, see the examples:
    <https://github.com/hedgehogqa/haskell-hedgehog/tree/master/hedgehog-example>
category: Testing
abi: 3149bf2451511b0290202019a81f7cbf
exposed: True
exposed-modules:
    Hedgehog Hedgehog.Gen Hedgehog.Internal.Config
    Hedgehog.Internal.Discovery Hedgehog.Internal.Distributive
    Hedgehog.Internal.Exception Hedgehog.Internal.Gen
    Hedgehog.Internal.HTraversable Hedgehog.Internal.Opaque
    Hedgehog.Internal.Property Hedgehog.Internal.Queue
    Hedgehog.Internal.Range Hedgehog.Internal.Region
    Hedgehog.Internal.Report Hedgehog.Internal.Runner
    Hedgehog.Internal.Seed Hedgehog.Internal.Show
    Hedgehog.Internal.Shrink Hedgehog.Internal.Source
    Hedgehog.Internal.State Hedgehog.Internal.TH Hedgehog.Internal.Tree
    Hedgehog.Internal.Tripping Hedgehog.Range
import-dirs: /usr/lib/ghc-8.4.3/site-local/hedgehog-0.6.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/hedgehog-0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hedgehog-0.6.1
hs-libraries: HShedgehog-0.6.1-IgAF1DmaXgkJa0UuqSnSwG
depends:
    base-4.11.1.0 ansi-terminal-0.8.1-72nCTUZRZdJG8ztHzhbgjc
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe bytestring-0.10.8.2
    concurrent-output-1.10.7-Eqi1YCbhDHRDCqbPsfBejr containers-0.5.11.0
    directory-1.3.1.5 exceptions-0.10.0-4E5CMyEcw7c5SGR3xFIeNi
    lifted-async-0.10.0.2-KxbSMLWSVn2IuAvlc5XaT1
    mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt
    monad-control-1.0.2.3-4ughhLHj9Ka6p4m5wwuexX mtl-2.2.2
    pretty-show-1.8.2-KRA90Zl1RBkEqIFTMdr4WM
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    resourcet-1.2.1-3KYZBJL4a2rBVLKWvBKB4Q stm-2.4.5.0
    template-haskell-2.13.0.0 text-1.2.3.0
    th-lift-0.7.11-EZ6htAQX8IAAgCBukhymGr time-1.8.0.2
    transformers-0.5.5.0
    transformers-base-0.4.5.2-CPMQOTuCPA6G978LVAIlzh
    wl-pprint-annotated-0.1.0.1-D5RYhowxdoJJSZqcdmkEu9 unix-2.7.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ansi-terminal-0.8.1-72nCTUZRZdJG8ztHzhbgjc=ac560d64fefa05d8067fac44b9aaa9de
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=32776142fda961cc693aa4db742773f9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             concurrent-output-1.10.7-Eqi1YCbhDHRDCqbPsfBejr=02a3ad5b67bc6899071767e0e109c22a
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             exceptions-0.10.0-4E5CMyEcw7c5SGR3xFIeNi=b417f0870e3d66d725c431d901a306c8
             lifted-async-0.10.0.2-KxbSMLWSVn2IuAvlc5XaT1=0de9fe83cfdafd0b3f86e85bb1618528
             mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt=a11d1b6072309591a730a4f5ac739aa1
             monad-control-1.0.2.3-4ughhLHj9Ka6p4m5wwuexX=ccfd06c57089143c2e021ca11cc4fff5
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             pretty-show-1.8.2-KRA90Zl1RBkEqIFTMdr4WM=fe1c8cd990a59160567f7942ed9f9a72
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=0a8d9e3ca28de3a4ac62e5f0044fa23c
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             resourcet-1.2.1-3KYZBJL4a2rBVLKWvBKB4Q=b5273090c64c1efd0c4504885cc2bdef
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             th-lift-0.7.11-EZ6htAQX8IAAgCBukhymGr=3abe31b2134622b7b297c47726ab60c8
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-base-0.4.5.2-CPMQOTuCPA6G978LVAIlzh=24d243b13204b0d99b0f7fc5f56cecfb
             wl-pprint-annotated-0.1.0.1-D5RYhowxdoJJSZqcdmkEu9=dde936a3dd244ddce2795fcc929eaf1c
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-hedgehog/html/hedgehog.haddock
haddock-html: /usr/share/doc/haskell-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hedgehog-0.6.1-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hedgehog
version: 0.6.1
id: hedgehog-0.6.1-L3QVTDBSZvV3Mv2I1ue7es
key: hedgehog-0.6.1-L3QVTDBSZvV3Mv2I1ue7es
license: BSD-3-Clause
maintainer: Jacob Stanley <jacob@stanley.io>
author: Jacob Stanley
homepage: https://hedgehog.qa
synopsis: Hedgehog will eat all your bugs.
description:
    Hedgehog is a modern property-based testing system, in the spirit of
    QuickCheck. Hedgehog uses integrated shrinking, so shrinks obey the
    invariants of generated values by construction.
    .
    To get started quickly, see the examples:
    <https://github.com/hedgehogqa/haskell-hedgehog/tree/master/hedgehog-example>
category: Testing
abi: c5a93461a91c1945da74aed945c4717d
exposed: True
exposed-modules:
    Hedgehog Hedgehog.Gen Hedgehog.Internal.Config
    Hedgehog.Internal.Discovery Hedgehog.Internal.Distributive
    Hedgehog.Internal.Exception Hedgehog.Internal.Gen
    Hedgehog.Internal.HTraversable Hedgehog.Internal.Opaque
    Hedgehog.Internal.Property Hedgehog.Internal.Queue
    Hedgehog.Internal.Range Hedgehog.Internal.Region
    Hedgehog.Internal.Report Hedgehog.Internal.Runner
    Hedgehog.Internal.Seed Hedgehog.Internal.Show
    Hedgehog.Internal.Shrink Hedgehog.Internal.Source
    Hedgehog.Internal.State Hedgehog.Internal.TH Hedgehog.Internal.Tree
    Hedgehog.Internal.Tripping Hedgehog.Range
import-dirs: /usr/lib/ghc-8.4.3/site-local/hedgehog-0.6.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/hedgehog-0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hedgehog-0.6.1
hs-libraries: HShedgehog-0.6.1-L3QVTDBSZvV3Mv2I1ue7es
depends:
    base-4.11.1.0 ansi-terminal-0.8.1-72nCTUZRZdJG8ztHzhbgjc
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe bytestring-0.10.8.2
    concurrent-output-1.10.7-Eqi1YCbhDHRDCqbPsfBejr containers-0.5.11.0
    directory-1.3.1.5 exceptions-0.10.0-4E5CMyEcw7c5SGR3xFIeNi
    lifted-async-0.10.0.3-K8q4pkB6MowHVgMq1mbTKe
    mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt
    monad-control-1.0.2.3-4ughhLHj9Ka6p4m5wwuexX mtl-2.2.2
    pretty-show-1.8.2-KRA90Zl1RBkEqIFTMdr4WM
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    resourcet-1.2.1-3KYZBJL4a2rBVLKWvBKB4Q stm-2.4.5.0
    template-haskell-2.13.0.0 text-1.2.3.0
    th-lift-0.7.11-EZ6htAQX8IAAgCBukhymGr time-1.8.0.2
    transformers-0.5.5.0
    transformers-base-0.4.5.2-CPMQOTuCPA6G978LVAIlzh
    wl-pprint-annotated-0.1.0.1-D5RYhowxdoJJSZqcdmkEu9 unix-2.7.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ansi-terminal-0.8.1-72nCTUZRZdJG8ztHzhbgjc=ac560d64fefa05d8067fac44b9aaa9de
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=32776142fda961cc693aa4db742773f9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             concurrent-output-1.10.7-Eqi1YCbhDHRDCqbPsfBejr=02a3ad5b67bc6899071767e0e109c22a
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             exceptions-0.10.0-4E5CMyEcw7c5SGR3xFIeNi=b417f0870e3d66d725c431d901a306c8
             lifted-async-0.10.0.3-K8q4pkB6MowHVgMq1mbTKe=d51df98647312c514c7b5021c1f73282
             mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt=a11d1b6072309591a730a4f5ac739aa1
             monad-control-1.0.2.3-4ughhLHj9Ka6p4m5wwuexX=ccfd06c57089143c2e021ca11cc4fff5
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             pretty-show-1.8.2-KRA90Zl1RBkEqIFTMdr4WM=fe1c8cd990a59160567f7942ed9f9a72
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=0a8d9e3ca28de3a4ac62e5f0044fa23c
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             resourcet-1.2.1-3KYZBJL4a2rBVLKWvBKB4Q=b5273090c64c1efd0c4504885cc2bdef
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             th-lift-0.7.11-EZ6htAQX8IAAgCBukhymGr=3abe31b2134622b7b297c47726ab60c8
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-base-0.4.5.2-CPMQOTuCPA6G978LVAIlzh=24d243b13204b0d99b0f7fc5f56cecfb
             wl-pprint-annotated-0.1.0.1-D5RYhowxdoJJSZqcdmkEu9=dde936a3dd244ddce2795fcc929eaf1c
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-hedgehog/html/hedgehog.haddock
haddock-html: /usr/share/doc/haskell-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
